@@ -8,6 +8,8 @@ import (
 	"strings"
 	"time"
 
+	"k8s.io/kubernetes/staging/src/k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
+
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/session"
 	"github.com/aws/aws-sdk-go/service/route53"
@@ -134,9 +136,9 @@ var _ = g.Describe("[Feature:DisasterRecovery][Disruptive]", func() {
 				}
 
 				framework.Logf("Perform etcd backup on remaining machine %s (machine %s)", survivingNodeName, survivingMachineName)
-				expectSSH("sudo rm -f /root/assets/backup/snapshot.db; sudo -i /bin/bash -x /usr/local/bin/etcd-snapshot-backup.sh /root/assets/backup/snapshot.db", survivingNode)
+				expectSSH("sudo -i /bin/bash -c 'rm -f /root/assets/backup/snapshot*'; sudo -i /bin/bash -x /usr/local/bin/etcd-snapshot-backup.sh /root/assets/backup", survivingNode)
 				framework.Logf("Restore etcd on remaining node %s (machine %s)", survivingNodeName, survivingMachineName)
-				expectSSH(fmt.Sprintf("sudo -i /bin/bash -x /usr/local/bin/etcd-snapshot-restore.sh /root/assets/backup/snapshot.db %s", etcdConnectionString), survivingNode)
+				expectSSH(fmt.Sprintf("sudo -i /bin/bash -c '/bin/bash -x /usr/local/bin/etcd-snapshot-restore.sh /root/assets/backup/snapshot* %s'", etcdConnectionString), survivingNode)
 
 				framework.Logf("Wait for API server to come up")
 				time.Sleep(30 * time.Second)
@@ -160,13 +162,17 @@ var _ = g.Describe("[Feature:DisasterRecovery][Disruptive]", func() {
 						}
 						framework.Logf("Creating master %s", master)
 						newMaster := survivingMachine.DeepCopy()
+						// The providerID is relied upon by the machine controller to determine a machine
+						// has been provisioned
+						// https://github.com/openshift/cluster-api/blob/c4a461a19efb8a25b58c630bed0829512d244ba7/pkg/controller/machine/controller.go#L306-L308
+						unstructured.SetNestedField(newMaster.Object, "", "spec", "providerID")
 						newMaster.SetName(master)
 						newMaster.SetResourceVersion("")
 						newMaster.SetSelfLink("")
 						newMaster.SetUID("")
 						newMaster.SetCreationTimestamp(metav1.NewTime(time.Time{}))
 						// retry until the machine gets created
-						err := wait.PollImmediate(5*time.Second, 5*time.Minute, func() (bool, error) {
+						err := wait.PollImmediate(5*time.Second, 10*time.Minute, func() (bool, error) {
 							_, err := ms.Create(newMaster, metav1.CreateOptions{})
 							if errors.IsAlreadyExists(err) {
 								framework.Logf("Waiting for old machine object %s to be deleted so we can create a new one", master)
